@@ -1,12 +1,27 @@
-#!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-import re
+import regex as re
 import sys
 import traceback
 import mysql
 import mysql.connector
 from mysql.connector import errorcode
 
+'''
+config default set
+
+config = {
+    "host": '127.0.0.1',
+    "user": 'root',
+    'password': 'root',
+    'database': 'test',
+    'port': '3306',
+    'dbms': 'mysql',
+    'charset': 'utf8',
+    'debug': True,
+    'autocommit': True
+}
+'''
+
 def is_numeric(var):
     try:
         float(var)
@@ -17,7 +32,7 @@ def is_numeric(var):
 def pdo_quote(string):
     return "'" + re.sub(r'(?<=[^\\])([\'\"])', r'\\\1', str(string)) + "'"
 
-class pythonMySQL(object):
+class db():
     configs = {}
     links = {}
     NumberLink = 0
@@ -52,7 +67,8 @@ class pythonMySQL(object):
 
     SQL_logic = ['AND', 'OR', 'XOR']
 
-    def __init__(self, dbtable, dbConfig):
+    #connecton
+    def connection(self,dbConfig):
         self.columns = []
         self.whereStringArray = []
         self.whereValueArray = []
@@ -62,31 +78,26 @@ class pythonMySQL(object):
             if dbConfig['debug'] == True:
                 self.dbdebug = True
             del dbConfig['debug']
-            
+
         if 'password' not in dbConfig:
                 self.throw_exception('database password no set')
-            
+
         if 'host' not in dbConfig:
             dbConfig['host'] = '127.0.0.1'
-            
+
         if 'user' not in dbConfig:
             dbConfig['user'] = 'root'
-            
+
         if 'port' not in dbConfig:
             dbConfig['port'] = '3306'
-            
+
         if 'autocommit' not in dbConfig:
             dbConfig['autocommit'] = True
-            
-        if 'dbms' not in dbConfig:
-            dbConfig['dbms'] = 'mysql'
-            self.throw_exception('database type no set')
 
-        pythonMySQL.configs[0] = dbConfig
+        db.configs[0] = dbConfig
         self.current = 0
         self.config = dbConfig
         self.database = dbConfig['database']
-        del dbConfig['dbms']
 
         try:
             self.con = mysql.connector.connect(**dbConfig)
@@ -99,23 +110,20 @@ class pythonMySQL(object):
             else:
                 msg = err
             self.throw_exception('connection error：' + msg)
-        # 设置 self.link, self.table_name, self.connected
         if self.cur:
-            pythonMySQL.links[self.current] = self.con
+            db.links[self.current] = self.con
         else:
             self.throw_exception('connection error')
-        if self.in_db(dbtable):
-            self.table_name = dbtable
-        else:
-            self.throw_exception('database' + dbConfig['database'] + 'no exsit' + dbtable + 'table')
+
         self.connected = True
-        pythonMySQL.NumberLink += 1
+        db.NumberLink += 1
+        return self
 
     # init
     def init(self, current, dbtable):
         self.current = current
-        self.config = pythonMySQL.configs[current]
-        self.con = pythonMySQL.links[current]
+        self.config = db.configs[current]
+        self.con = db.links[current]
         self.cur = self.con.cursor(dictionary=True)
         if 'debug' in self.config and self.config['debug'] == True:
             self.dbdebug = True
@@ -617,7 +625,7 @@ class pythonMySQL(object):
         for key, val in data.items():
             if isinstance(val, (list, tuple)):
                 # 支持exp表达式进行数据更新
-                if val[0].upper == 'EXP':
+                if val[0].upper() == 'EXP':
                     if key.find('.') == -1:
                         setFieldStr += '`' + key.strip() + '` = ' + val[1].strip() + ','
                     else:
@@ -722,18 +730,18 @@ class pythonMySQL(object):
     # isolation_level: permitted values are 'READ UNCOMMITTED', 'READ COMMITTED', 'REPEATABLE READ', and 'SERIALIZABLE'
     # The readonly argument can be True to start the transaction in READ ONLY mode or False to start it in READ WRITE mode. If readonly is omitted, the server's default access mode is used.
     def startTrans(self, consistent_snapshot=False, isolation_level=None, readonly=False):
-        for link in pythonMySQL.links.values():
+        for link in db.links.values():
             link.start_transaction(consistent_snapshot, isolation_level, readonly)
 
     def inTrans(self):
         return self.con.in_transaction
 
     def rollback(self):
-        for link in pythonMySQL.links.values():
+        for link in db.links.values():
             link.rollback()
 
     def commit(self):
-        for link in pythonMySQL.links.values():
+        for link in db.links.values():
             link.commit()
 
     def getLastSql(self):
@@ -1111,15 +1119,9 @@ class pythonMySQL(object):
             for i in range(length - 1):
                 print(traceback.format_stack()[i])
         else:
-            errMsg = "system error"
+            errMsg = "error happen"
             print(errMsg)
         sys.exit(0)
 
-# db method
-def db(table, config=None):
-    if config is None:
-        config = {}
-    return pythonMySQL(table,config)
-
 if __name__ == '__main__':
     print('mysql orm for humans')
